/* LOCKVC Version 3.6 (c) 1994,1995,1997 by Matthias Straub */
/* shadow-password option added by Ed Beaumont */
/* this file was released under GPL */
/* see COPYING for details */

#include <vga.h>
#include <stdio.h>
#include <stdlib.h>

#include "lockvc.h"

unsigned char *screen;
unsigned char *rscreen;
unsigned char *escreen;

unsigned short zuf=1777;
unsigned short zufm=31317;

void draw_feuer()
     {
	unsigned char *lscreen;
	
	for(lscreen=screen+200*320;lscreen<(screen+201*320);lscreen++)
	  {
	     if((zuf*=zufm)<17000) *lscreen=191;
	     else *lscreen=0;
	  }
	
	for(lscreen=screen+80*320;lscreen<escreen;lscreen++)
	  {
	     *lscreen=(*lscreen+*(lscreen+321)+*(lscreen+319)+*(lscreen+640))/4;
	  }
	memcpy(rscreen+80*320,screen+80*320,120*320);
	if(vga_getkey()!=0 && vga_getkey()!=-1)authenticate();
	vga_waitretrace(); 

     }

void feuer()
{
   int i;

   vga_init();
   vga_setmode(G320x200x256);
   signals();
   screen=(char *)malloc(64320);
   rscreen=vga_getgraphmem();
   
   for(i=0;i<32;i++)
     {
	vga_setpalette(i    ,   i*2,0     ,0);
	vga_setpalette(i+32 ,63,20+i/2  ,0);
	vga_setpalette(i+64 ,63,36+i/2  ,0);
	vga_setpalette(i+96 ,63 , 55 ,i);
	vga_setpalette(i+128,63, 63, i);
     }
   escreen=screen+320*200;
   while(1)
     {
	draw_feuer();
     }
}

